#pragma once
/* 
* Copyright (C) 2024 Dominik Meyer
*  
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*  
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*  
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/
#include "Redmine/Filter.hpp"
#include "Redmine/Project.hpp"
#include "nlohmann/json_fwd.hpp"
#include <CLI/App.hpp>
#include <Redmine/API.hpp>
#include <atomic>
#include <cstdint>
#include <memory>
#include <string>
#include <vector>
#define LOGURU_WITH_STREAMS 1
#include <loguru.hpp>
#include <CLI/CLI.hpp>


// forward declaration
namespace RedmineCLI 
{
    class Redmine;
};

namespace Command
{

    /**
    * @brief class for processing the CLI11 parsed command lines
    * 
    */
    class Issue 
    {

        private:

            /// the main redmine cli application context
            RedmineCLI::Redmine *redmine_;

            /// enum for identifying supported output types
            enum outputType : std::uint16_t 
            {
                /// output is just text
                TEXT,
                /// output is json
                JSON
            };

            /// requested output type
            outputType output_;

            std::map<std::string, outputType> outputMap{{"text", TEXT}, {"json", JSON}};

            /// vector to hold requested attribute fields
            std::vector<std::string> fields_;

            /// the project id to work on
            std::int64_t projectId_;

            /// the userid to filter on
            std::uint64_t userId_;
            
            /// the status to filter on
            std::string status_;

            /// pointer to the list subcommand
            CLI::App* list_;


            void printIssueListJson_(const std::vector<Redmine::Issue> &issues) const;

            void printIssueListText_(const std::vector<Redmine::Issue> &issues) const;

            /// the actual implementation of the list command
            void getList_() const;

        public:
            /**
            * @brief Construct a new CLIProcessor object
            * 
            */
            explicit Issue(RedmineCLI::Redmine *r);
            
    }; // class Issue
}; // namespace Command