#pragma once
/* 
* Copyright (C) 2024 Dominik Meyer
*  
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*  
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*  
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/
#include "Redmine/Project.hpp"
#include "nlohmann/json_fwd.hpp"
#include <CLI/App.hpp>
#include <Redmine/API.hpp>
#include <atomic>
#include <cstdint>
#include <memory>
#include <string>
#include <vector>
#define LOGURU_WITH_STREAMS 1
#include <loguru.hpp>
#include <CLI/CLI.hpp>


// forward declaration
namespace RedmineCLI 
{
    class Redmine;
};

namespace Command
{

    /**
    * @brief class for processing the CLI11 parsed command lines
    * 
    */
    class Project 
    {

        private:

            /// the main redmine cli application context
            RedmineCLI::Redmine *redmine_;

            /// enum for identifying supported output types
            enum outputType : std::uint16_t 
            {
                /// output is just text
                TEXT,
                /// output is json
                JSON
            };

            /// requested output type
            outputType output_;

            std::map<std::string, outputType> outputMap{{"text", TEXT}, {"json", JSON}};

            /// vector to hold requested attribute fields
            std::vector<std::string> fields_;

            /// the project id to work on
            std::uint64_t projectId_;

            /// the file path for uploading files
            std::string filePath_;

            /// the filename for uploading files
            std::string fileName_;

            /// the description for uploading files
            std::string fileDescription_;

            /// the version of the uploading files
            std::uint32_t fileVersion_;

            /// the maximum number of projects to list
            std::uint32_t limit_; 

            /// pointer to the list subcommand
            CLI::App* list_;

            /// pointer to the upload subcommand
            CLI::App* upload_;
            
            /// point to the list issues subcommand
            CLI::App* issuesList_;

            
            /**
             * @brief method to print the project list
             * 
             * @param projects - the projects to print in json
             */
            void printProjectList_(const std::vector<Redmine::Project> &projects) const;

            void printProjectListJson_(const std::vector<Redmine::Project> &projects, bool printName, bool printID, bool printIdentifier) const;

            void printProjectListText_(const std::vector<Redmine::Project> &projects, bool printName, bool printID, bool printIdentifier) const;

            /// the actual implementation of the list command
            void getList_() const;

            void uploadFile_() const;
        public:
            /**
            * @brief Construct a new CLIProcessor object
            * 
            */
            explicit Project(RedmineCLI::Redmine *r);
            
    }; // class Project
}; // namespace Command