/* 
* Copyright (C) 2024 Dominik Meyer
*  
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*  
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*  
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/
#include <Redmine-CLI/Command/MyAccount.hpp>
#include "Redmine-CLI/Command/IssueStatus.hpp"
#include "Redmine-CLI/Command/Version.hpp"
#include <Redmine-CLI/Redmine.hpp>
#include <memory>
#define LOGURU_WITH_STREAMS 1
#include <loguru.hpp>


RedmineCLI::Redmine::Redmine(CLI::App &cli)
:
cli_(cli),
version_(nullptr)
{

    CLIredmineApiToken_ = cli_.add_option("-t,--token",redmineApiToken_,
                                         "The API token for accessing redmine")->envname("REDMINE_API_TOKEN");
    
    CLIredmineUrl_ = cli_.add_option("-u,--url",redmineUrl_,"The URL to the redmine server (e.g. https://redmine.org)")->envname("REDMINE_URL");


    // add all commands here
    version_        = std::make_unique<Command::Version>(this);
    myAccount_      = std::make_unique<Command::MyAccount>(this);
    project_          = std::make_unique<Command::Project>(this);
    issueStatus_    = std::make_unique<Command::IssueStatus>(this);
    issue_          = std::make_unique<Command::Issue>(this);
}