/* 
* Copyright (C) 2024 Dominik Meyer
*  
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*  
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*  
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/
#include <Redmine/Filter.hpp>
#include <sstream>

Redmine::Filter::Filter() 
    :
    filterByProjectID_(false),
    projectStatus_(Redmine::Filter::ProjectStatus::open),
    filterByAssignedUser_(false)
    {

    }

void Redmine::Filter::filterByProjectID(const std::uint64_t id)
{
    filterByProjectID_ = true;
    projectID_ = id;
}

void Redmine::Filter::filterByAssignedUserId(const std::uint64_t id)
{
    filterByAssignedUser_ = true;
    assignedUserID_ = id;
}

std::string Redmine::Filter::toQueryString() const
{
    std::stringstream filter;

    if (filterByProjectID_)
    {
        filter << "project_id=" << projectID_ << "&";
    }

    switch (projectStatus_)
    {
        case Redmine::Filter::ProjectStatus::both:
            filter << "status_id=*";
            break;
        
        case Redmine::Filter::ProjectStatus::open:
            filter << "status=open";
            break;

        case Redmine::Filter::ProjectStatus::closed:
            filter << "status=closed";
            break;
    }; // switch projectStatus

    if (filterByAssignedUser_)
    {
        if (filter.rdbuf()->in_avail() > 0)
        {
            filter << "&";
        }
        filter << "assigned_to_id=" << assignedUserID_;
    }
    
    return filter.str();
}